﻿using Aquaforest.PDF;
using System;
using System.Collections.Generic;
using System.IO;

namespace PDFToolkitCMD
{
    internal class BookmarksAttachments
    {
        public static void ProcessFile(string input, PDFToolkitArguements toolkitArgs)
        {
            if (!Path.GetExtension(input).ToLower().Contains("pdf"))
            {
                Console.WriteLine("Input File {0} must be a pdf File", input);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
                else
                {
                    return;
                }
            }
            switch (toolkitArgs.Operation.ToLower().Trim())
            {
                case "insertattachment":
                    {
                        DoAttachment(input, toolkitArgs);
                    }
                    break;

                case "insertbookmarks":
                    {
                        DoBookmarks(input, toolkitArgs);
                    }
                    break;
            }
        }

        private static void DoAttachment(string input, PDFToolkitArguements toolkitArgs)
        {
            if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
            {
                toolkitArgs.OutputFile = "%filename_attachment.pdf";
            }

            string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
            try
            {
                if (!string.IsNullOrEmpty(toolkitArgs.Attachments))
                {
                    List<PDFAttachmentItem> toolkitAttachment = new List<PDFAttachmentItem>();
                    var attachments = toolkitArgs.Attachments.Split(';');
                    string filePath = string.Empty;
                    foreach (var attachment in attachments)
                    {
                        filePath = Path.GetFullPath(attachment);
                        if (File.Exists(filePath))
                        {
                            toolkitAttachment.Add(new PDFAttachmentItem(filePath));
                        }
                        else
                        {
                            Console.WriteLine("{0} does not exist, skipping file..", attachment);
                        }
                    }
                    PDFDocument document = new PDFDocument(input);

                    document.EmbedPDFAttachments(toolkitAttachment);
                    document.Save(target);
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);

                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }

        private static void DoBookmarks(string input, PDFToolkitArguements toolkitArgs)
        {
            if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
            {
                toolkitArgs.OutputFile = "%filename_bookmarks.pdf";
            }

            string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
            try
            {
                if (!string.IsNullOrEmpty(toolkitArgs.Bookmarks))
                {
                    List<PDFBookmarkItem> toolkitBookmarks = new List<PDFBookmarkItem>();
                    int page = 0;
                    var bookmarks = toolkitArgs.Bookmarks.Split(';');
                    PDFDocument document = new PDFDocument(input);
                    foreach (var item in bookmarks)
                    {
                        var bookmark = item.Split(':');
                        try
                        {
                            page = Convert.ToInt32(bookmark[1]);
                            toolkitBookmarks.Add(new PDFBookmarkItem(page, bookmark[0]));
                        }
                        catch (Exception)
                        {
                            Console.WriteLine("Sorry we cannot convert one of your bookmark Page numbers to an integer.");
                            Environment.Exit(1);
                        }
                        PDFBookmark pdfBookmark = new PDFBookmark();
                        pdfBookmark.BookmarkHeader = "Example 1";
                        pdfBookmark.BookmarkItems.AddRange(toolkitBookmarks);

                        document.AddBookmarks(pdfBookmark);
                    }
                    document.Save(target);
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);

                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }
    }
}