﻿using Aquaforest.PDF;
using Aquaforest.PDF.Font;
using System;
using System.IO;

namespace PDFToolkitCMD
{
    internal class CSVPDFA
    {
        public static void ProcessFile(string input, PDFToolkitArguements toolkitArgs)
        {
            try
            {
                //Assign Licence Key

                if (Path.GetExtension(input).ToLower() != ".csv")
                {
                    Console.WriteLine("Input File {0} must be a csv File", input);
                    if (!toolkitArgs.OnErrorContinue)
                    {
                        Console.WriteLine("Halting Job Because Continue On Error is set to false");
                        Environment.Exit(1);
                    }
                    else
                    {
                        return;
                    }
                }

                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_csv.pdf";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
                Console.WriteLine("Converting : " + Path.GetFullPath(input) + " to a pdf file.");
                CSVToPDFConverter csvConverter = new CSVToPDFConverter(input);
                PDFPageSettings PageSetting = new PDFPageSettings();
                PageSetting.SetMargin(toolkitArgs.LeftMargin, toolkitArgs.RightMargin, toolkitArgs.TopMargin, toolkitArgs.BottomMargin);
                if (toolkitArgs.Font != null)
                {
                    PageSetting.Font = PDFType1Font.GetStandardFont(toolkitArgs.Font);
                }
                if (toolkitArgs.FontSize > 0)
                {
                    PageSetting.FontSize = toolkitArgs.FontSize;
                }
                if (toolkitArgs.RowHeight > 0)
                {
                    PDFTableSettings tableSettings = new PDFTableSettings();
                    tableSettings.CellMargin = toolkitArgs.CellMargin;
                    tableSettings.RowHeight = toolkitArgs.RowHeight;
                    csvConverter.ConvertToPDF(target, PageSetting, tableSettings);
                }
                else
                {
                    csvConverter.ConvertToPDF(target, PageSetting);
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }

        public static void ConvertToPDFA(string input, PDFToolkitArguements toolkitArgs)
        {
            try
            {
                if (Path.GetExtension(input).ToLower() != ".pdf")
                {
                    Console.WriteLine("Input File {0} must be a pdf File", input);
                    if (!toolkitArgs.OnErrorContinue)
                    {
                        Console.WriteLine("Halting Job Because Continue On Error is set to false");
                        Environment.Exit(1);
                    }
                    else
                    {
                        return;
                    }
                }

                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_pdfa.pdf";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
                Console.WriteLine("Converting : " + Path.GetFullPath(input) + " to a pdfa file.");
                AquaforestPDFAFlavour flavour = AquaforestPDFAFlavour.PDFA_1_B;
                switch (toolkitArgs.PDFAVersion)
                {
                    case "0":
                        {
                            flavour = AquaforestPDFAFlavour.PDFA_1_A;
                        }
                        break;

                    case "1":
                        {
                            flavour = AquaforestPDFAFlavour.PDFA_1_B;
                        }
                        break;

                    case "2":
                        {
                            flavour = AquaforestPDFAFlavour.PDFA_2_A;
                        }
                        break;

                    case "3":
                        {
                            flavour = AquaforestPDFAFlavour.PDFA_2_B;
                        }
                        break;

                    case "4":
                        {
                            flavour = AquaforestPDFAFlavour.PDFA_2_U;
                        }
                        break;

                    case "5":
                        {
                            flavour = AquaforestPDFAFlavour.PDFA_3_A;
                        }
                        break;

                    case "6":
                        {
                            flavour = AquaforestPDFAFlavour.PDFA_3_B;
                        }
                        break;

                    case "7":
                        {
                            flavour = AquaforestPDFAFlavour.PDFA_3_U;
                        }
                        break;
                }
                PDF2PDFaConverter pdfaConverter = new PDF2PDFaConverter(input, target, flavour);
                //Convert File to PDFa
                pdfaConverter.ConvertToPDFA();
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }
    }
}