﻿using Aquaforest.PDF;
using System;
using System.IO;

namespace PDFToolkitCMD
{
    internal class ExtractText
    {
        public static void ProcessFile(string input, PDFToolkitArguements toolkitArgs)
        {
            if (Path.GetExtension(input).ToLower() != ".pdf")
            {
                Console.WriteLine("Input File {0} must be a pdf File", input);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
                else
                {
                    return;
                }
            }
            switch (toolkitArgs.Operation.ToLower().Trim())
            {
                case "extracttext":
                    {
                        ExtractTextNormal(input, toolkitArgs);
                    }
                    break;

                case "extracttexthocr":
                    {
                        EtractTextHocr(input, toolkitArgs);
                    }
                    break;
            }
        }

        private static void ExtractTextNormal(string input, PDFToolkitArguements toolkitArgs)
        {
            try
            {
                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_extract.txt";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
                Console.WriteLine("Extracting text from : " + Path.GetFullPath(input));
                PDFDocument pdfFile;
                target = Path.Combine(Path.GetDirectoryName(target), Path.GetFileNameWithoutExtension(target) + ".txt");
                string pageText = string.Empty;
                if (toolkitArgs.Password == null)
                {
                    pdfFile = new PDFDocument(input);
                }
                else
                {
                    pdfFile = new PDFDocument(input, toolkitArgs.Password);
                }

                if (toolkitArgs.PageNumber == -1)
                {
                    File.WriteAllText(target, pdfFile.GetText());
                }
                else
                {
                    File.WriteAllText(target, pdfFile.GetText(toolkitArgs.PageNumber));
                }
                pdfFile.Close();
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }

        private static void EtractTextHocr(string input, PDFToolkitArguements toolkitArgs)
        {
            try
            {
                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_office";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
                Console.WriteLine("Extracting text from : " + Path.GetFullPath(toolkitArgs.Source));
                PDFDocument pdfFile;
                target = Path.Combine(Path.GetDirectoryName(target), Path.GetFileNameWithoutExtension(target) + ".txt");
                string pageText = string.Empty;
                if (toolkitArgs.Password == null)
                {
                    pdfFile = new PDFDocument(input);
                }
                else
                {
                    pdfFile = new PDFDocument(input, toolkitArgs.Password);
                }

                pdfFile.GenerateHocrFromText(target, true);

                pdfFile.Close();
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }
    }
}