﻿using Aquaforest.PDF;
using System;
using System.IO;

namespace PDFToolkitCMD
{
    internal class ImageHandler
    {
        public static void ProcessFile(string input, PDFToolkitArguements toolkitArgs)
        {
            switch (toolkitArgs.Operation.ToLower().Trim())
            {
                case "imagetopdf":
                    {
                        ConvertImageToPDF(input, toolkitArgs);
                    }
                    break;

                case "extarctimages":
                    {
                        ExtractImages(input, toolkitArgs);
                    }
                    break;
            }
        }

        private static void ExtractImages(string input, PDFToolkitArguements toolkitArgs)
        {
            try
            {
                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_img";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
                PDFDocument pdfFile;
                string pre = toolkitArgs.OutputFile;
                if (toolkitArgs.Password == null)
                    pdfFile = new PDFDocument(toolkitArgs.Source);
                else
                    pdfFile = new PDFDocument(toolkitArgs.Source, toolkitArgs.Password);
                PDFImageExtractor imageExtractor = new PDFImageExtractor(pdfFile);
                if (toolkitArgs.PageNumber > 0)
                {
                    imageExtractor.ExtractImages(target, pre, true, toolkitArgs.PageNumber);
                }
                else
                {
                    imageExtractor.ExtractImages(target, pre, true);
                }

                pdfFile.Close();
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }

        private static void ConvertImageToPDF(string input, PDFToolkitArguements toolkitArgs)
        {
            try
            {
                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_image.pdf";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
                ImageToPDFConverter image = new ImageToPDFConverter(input, target);
                image.ConvertImageToPDF();
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }
    }
}