﻿using Aquaforest.Office.PDF;
using System;
using System.IO;

namespace PDFToolkitCMD
{
    internal class OfficeConversions
    {
        private static DocumentSettings GetSettingsFromArgs(PDFToolkitArguements toolkitArgs)
        {
            DocumentSettings setting = new DocumentSettings();
            if (toolkitArgs.Pdfa)
            {
                setting.PDFA1a = true;
            }
            if (toolkitArgs.IncludeProperty)
            {
                setting.IncludeDocumentProperty = true;
            }
            if (toolkitArgs.StartPage > 0)
            {
                setting.FromPage = toolkitArgs.StartPage;
            }
            if (toolkitArgs.EndPage > 0)
            {
                setting.ToPage = toolkitArgs.EndPage;
            }
            if (toolkitArgs.PageWidth > 0)
            {
                setting.PageWidth = toolkitArgs.PageWidth;
            }
            if (toolkitArgs.PageHeight > 0)
            {
                setting.PageHeight = toolkitArgs.PageHeight;
            }
            if (toolkitArgs.ConvertBookmark)
            {
                setting.BookmarkOption = AquaforestPDFBookmarks.BOOKMARKS_FROM_HEADINGS;
            }
            return setting;
        }

        public static void ProcessFile(string input, PDFToolkitArguements toolkitArgs)
        {
            if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
            {
                toolkitArgs.OutputFile = "%filename_office.pdf";
            }
            var settings = GetSettingsFromArgs(toolkitArgs);
            string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
            try
            {
                switch (toolkitArgs.Operation.ToLower())
                {
                    case "officeword":
                        {
                            WordToPDF wordPdf = new WordToPDF(input);
                            if (toolkitArgs.EmbedFont)
                            {
                                wordPdf.EmbedFonts = AquaforestFontEmbedding.EMBED_SUBSET;
                            }

                            wordPdf.ConvertToPDF(settings, target);
                        }
                        break;

                    case "officeexcel":
                        {
                            ExcelToPDF excelPdf = new ExcelToPDF(input);

                            excelPdf.ConvertToPDF(settings, target);
                        }
                        break;

                    case "officepub":
                        {
                            PublisherToPDF pubPdf = new PublisherToPDF(input);
                            pubPdf.ConvertToPDF(settings, target);
                        }
                        break;

                    case "officepower":
                        {
                            PowerPointToPDF powPdf = new PowerPointToPDF(input);
                            powPdf.ConvertToPDF(settings, target);
                        }
                        break;
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);

                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }
    }
}