﻿using Aquaforest.PDF;
using System;
using System.IO;

namespace PDFToolkitCMD
{
    internal class Overlay
    {
        public static void ProcessFile(string input, PDFToolkitArguements toolkitArgs)
        {
            try
            {
                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_overLay.pdf";
                }
                if (!Path.GetExtension(input).ToLower().Contains("pdf"))
                {
                    Console.WriteLine("Input File {0} must be a pdf File", input);
                    if (!toolkitArgs.OnErrorContinue)
                    {
                        Console.WriteLine("Halting Job Because Continue On Error is set to false");
                        Environment.Exit(1);
                    }
                    else
                    {
                        return;
                    }
                }
                if (!Path.GetExtension(toolkitArgs.Overlay).ToLower().Contains("pdf"))
                {
                    Console.WriteLine("Overlay File {0} must be a pdf File", toolkitArgs.Overlay);
                    if (!toolkitArgs.OnErrorContinue)
                    {
                        Console.WriteLine("Halting Job Because Continue On Error is set to false");
                        Environment.Exit(1);
                    }
                    else
                    {
                        return;
                    }
                }
                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
                Console.WriteLine("Overlaying : " + Path.GetFullPath(input) + " \nwith " + Path.GetFullPath(toolkitArgs.Overlay));
                PDFDocument baseDocument;
                PDFDocument overlayDocument;
                if (toolkitArgs.Password == null)
                {
                    baseDocument = new PDFDocument(input);
                    overlayDocument = new PDFDocument(toolkitArgs.Overlay);
                }
                else
                {
                    baseDocument = new PDFDocument(input, toolkitArgs.Password);
                    overlayDocument = new PDFDocument(toolkitArgs.Overlay, toolkitArgs.Password);
                }
                PDFOverlay over = new PDFOverlay(overlayDocument, baseDocument);
                over.ApplyOverlay(target);
                baseDocument.Close();
                overlayDocument.Close();
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }
    }
}