﻿using Aquaforest.PDF;
using System;
using System.IO;
using System.Xml;

namespace PDFToolkitCMD
{
    internal class SecurityMetadataHandler
    {
        public static void ProcessFile(string input, PDFToolkitArguements toolkitArgs)
        {
            if (!Path.GetExtension(input).ToLower().Contains("pdf"))
            {
                Console.WriteLine("Input File {0} must be a pdf File", input);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
                else
                {
                    return;
                }
            }
            switch (toolkitArgs.Operation)
            {
                case "AddMetadata":
                    {
                        DoMetadata(input, toolkitArgs);
                    }
                    break;

                case "AddPermission":
                    {
                        DoSecurity(input, toolkitArgs);
                    }
                    break;

                case "AddXMP":
                    {
                        DoXMP(input, toolkitArgs);
                    }
                    break;

                case "AddOpenSettings":
                    {
                        DoSettings(input, toolkitArgs);
                    }
                    break;
            }
        }

        private static void DoSecurity(string input, PDFToolkitArguements toolkitArgs)
        {
            try
            {
                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_permission.pdf";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
                PDFSecurity secure = new PDFSecurity();

                if (toolkitArgs.Permissions != null)
                {
                    PDFPermission Permissions = new PDFPermission();

                    if (toolkitArgs.Permissions.Contains("AllowAssembly"))
                    {
                        Permissions.AllowAssembly = false;
                    }
                    if (toolkitArgs.Permissions.Contains("AllowDegradedPrinting"))
                    {
                        Permissions.AllowDegradedPrinting = false;
                    }
                    if (toolkitArgs.Permissions.Contains("AllowExtractContents"))
                    {
                        Permissions.AllowExtractContents = false;
                    }
                    if (toolkitArgs.Permissions.Contains("AllowExtractForAccessibility"))
                    {
                        Permissions.AllowExtractForAccessibility = false;
                    }
                    if (toolkitArgs.Permissions.Contains("AllowFillInForm"))
                    {
                        Permissions.AllowFillInForm = false;
                    }
                    if (toolkitArgs.Permissions.Contains("AllowModifyAnnotations"))
                    {
                        Permissions.AllowModifyAnnotations = false;
                    }
                    if (toolkitArgs.Permissions.Contains("AllowModifyContents"))
                    {
                        Permissions.AllowModifyContents = false;
                    }
                    if (toolkitArgs.Permissions.Contains("AllowPrinting"))
                    {
                        Permissions.AllowPrinting = false;
                    }
                    secure.Permission = Permissions;
                }
                PDFDocument pdfFile;
                if (toolkitArgs.Password == null)
                {
                    pdfFile = new PDFDocument(input);
                }
                else
                {
                    pdfFile = new PDFDocument(input, toolkitArgs.Password);
                }
                secure.OwnerPassword = toolkitArgs.OwnerPassword;
                secure.UserPassword = toolkitArgs.UserPassword;
                secure.SecurePDF(pdfFile, target);
                pdfFile.Close();
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);

                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }

        private static void DoMetadata(string input, PDFToolkitArguements toolkitArgs)
        {
            try
            {
                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_metadata.pdf";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));

                if (!string.IsNullOrEmpty(toolkitArgs.Metadata))
                {
                    PDFDocumentInformation info = new PDFDocumentInformation();
                    var metadatas = toolkitArgs.Metadata.Split(';');
                    foreach (var data in metadatas)
                    {
                        //System.out.println("Att:"+attribute+" Val:"+value);
                        if (data.ToLower().Trim().StartsWith("author"))
                        {
                            info.Author = data.Split(':')[1];
                        }
                        if (data.ToLower().Trim().StartsWith("title"))
                        {
                            info.Title = data.Split(':')[1];
                        }
                        if (data.ToLower().Trim().StartsWith("subject"))
                        {
                            info.Subject = data.Split(':')[1];
                        }
                        if (data.ToLower().Trim().StartsWith("creator"))
                        {
                            info.Creator = data.Split(':')[1];
                        }
                        if (data.ToLower().Trim().StartsWith("keywords"))
                        {
                            info.Keywords = data.Split(':')[1];
                        }
                        if (data.ToLower().Trim().StartsWith("producer"))
                        {
                            info.Producer = data.Split(':')[1];
                        }
                    }
                    PDFDocument pdfFile;
                    if (toolkitArgs.Password == null)
                    {
                        pdfFile = new PDFDocument(input);
                    }
                    else
                    {
                        pdfFile = new PDFDocument(input, toolkitArgs.Password);
                    }
                    pdfFile.SetDocumentInformation(info);
                    pdfFile.Save(target);
                    pdfFile.Close();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);

                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }

        private static void DoSettings(string input, PDFToolkitArguements toolkitArgs)
        {
            try
            {
                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_setting.pdf";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
                if (!string.IsNullOrEmpty(toolkitArgs.OpenSettings))
                {
                    PDFDocument pdfFile;
                    if (toolkitArgs.Password == null)
                    {
                        pdfFile = new PDFDocument(input);
                    }
                    else
                    {
                        pdfFile = new PDFDocument(input, toolkitArgs.Password);
                    }
                    PDFDocumentOpenSetting openSettings = new PDFDocumentOpenSetting(pdfFile);
                    var settings = toolkitArgs.OpenSettings.Split(';');
                    foreach (var setting in settings)
                    {
                        if (setting.ToLower() == "pagelayoutsinglepage")
                        {
                            openSettings.PDFPageLayout = PageLayoutOptions.SINGLE_PAGE;
                        }

                        if (setting.ToLower() == "pagelayoutonecolumn")
                        {
                            openSettings.PDFPageLayout = PageLayoutOptions.ONE_COLUMN;
                        }

                        if (setting.ToLower() == "pagelayouttwocolumnleft")
                        {
                            openSettings.PDFPageLayout = PageLayoutOptions.TWO_COLUMN_LEFT;
                        }

                        if (setting.ToLower() == "pagelayouttwocolumnright")
                        {
                            openSettings.PDFPageLayout = PageLayoutOptions.TWO_COLUMN_RIGHT;
                        }

                        if (setting.ToLower() == "pagemodeusenone")
                        {
                            openSettings.PDFPageMode = PageModeOptions.USE_NONE;
                        }

                        if (setting.ToLower() == "pagemodeuseoutlines")
                        {
                            openSettings.PDFPageMode = PageModeOptions.USE_OUTLINES;
                        }

                        if (setting.ToLower() == "pagemodeusethumbs")
                        {
                            openSettings.PDFPageMode = PageModeOptions.USE_THUMBS;
                        }
                        if (setting.ToLower() == "pagemodefullscreen")
                        {
                            openSettings.PDFPageMode = PageModeOptions.FULL_SCREEN;
                        }

                        if (setting.ToLower() == "hidetoolbar")
                        {
                            openSettings.HideToolbar = true;
                        }
                        if (setting.ToLower() == "hidemenubar")
                        {
                            openSettings.HideMenubar = true;
                        }
                        if (setting.ToLower() == "hidewindowui")
                        {
                            openSettings.HideWindowUI = true;
                        }
                        if (setting.ToLower() == "fitwindow")
                        {
                            openSettings.FitWindow = true;
                        }
                        if (setting.ToLower() == "centerwindow")
                        {
                            openSettings.CenterWindow = true;
                        }

                        if (setting.ToLower() == "nonfullscreenpagemodeusenone")
                        {
                            openSettings.NonFullScreenPageMode = NonFullScreenModeOptions.UseNone;
                        }
                        if (setting.ToLower() == "nonfullscreenpagemodeusenoutline")
                        {
                            openSettings.NonFullScreenPageMode = NonFullScreenModeOptions.UseOutlines;
                        }
                        if (setting.ToLower() == "nonfullscreenpagemodeusethumbs")
                        {
                            openSettings.NonFullScreenPageMode = NonFullScreenModeOptions.UseThumbs;
                        }
                    }
                    openSettings.SaveOpenSettings(target);
                    pdfFile.Close();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);

                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }

        private static void DoXMP(string input, PDFToolkitArguements toolkitArgs)
        {
            if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
            {
                toolkitArgs.OutputFile = "%filename_xmp.pdf";
            }

            string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
            try
            {
                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_stamp.pdf";
                }
                if (string.IsNullOrEmpty(toolkitArgs.XmpFile))
                {
                    Console.WriteLine("Sorry, there was no XmpFile provided, exiting...");
                    Environment.Exit(1);
                }
                if (!File.Exists(toolkitArgs.XmpFile))
                {
                    Console.WriteLine("Sorry XmpFile {0}, does not exist, exiting...");
                    Environment.Exit(1);
                }

                XmlDocument xmp = new XmlDocument();
                xmp.Load(toolkitArgs.XmpFile);

                PDFDocument doc = new PDFDocument(input);
                doc.SetXMPMetadata(xmp);
                doc.Save(target);
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);

                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }
    }
}