﻿using Aquaforest.PDF;
using System;
using System.IO;
using System.Linq;

namespace PDFToolkitCMD
{
    internal class SplitMergePDFHandler
    {
        public static void ProcessSource(PDFToolkitArguements toolkitArgs)
        {
            if (toolkitArgs.SourceType == null || toolkitArgs.SourceType.ToLower() == "folder")
            {
                if (Directory.Exists(toolkitArgs.Source))
                {
                    RunMergeCommand(toolkitArgs.Source, toolkitArgs);
                }
                else
                {
                    Console.WriteLine("Sorry, we cannot find the input Directoy {0}", toolkitArgs.Source);
                    Environment.Exit(1);
                }
            }
            else if (toolkitArgs.SourceType.ToLower() == "tree")
            {
                if (Directory.Exists(toolkitArgs.Source))
                {
                    var AllFiles = Directory.GetDirectories(toolkitArgs.Source, "*.*", SearchOption.AllDirectories);
                    RunMergeCommand(toolkitArgs.Source, toolkitArgs);
                    foreach (var sourcefile in AllFiles)
                    {
                        RunMergeCommand(sourcefile, toolkitArgs);
                    }
                }
                else
                {
                    Console.WriteLine("Sorry, we cannot find the input Directoy {0}", toolkitArgs.Source);
                    Environment.Exit(1);
                }
            }
        }

        internal static void RunMergeCommand(string input, PDFToolkitArguements toolkitArgs)
        {
            switch (toolkitArgs.Operation.ToLower().Trim())
            {
                case "mergeimagestopdf":
                    {
                        MergeImageToPDF(toolkitArgs, input);
                    }
                    break;

                case "mergepdf":
                    {
                        MergePDFToPDF(toolkitArgs, input);
                    }
                    break;
            }
        }

        public static void MergeImageToPDF(PDFToolkitArguements toolkitArgs, string input)
        {
            try
            {
                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%dirname.pdf";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%dirname", (new DirectoryInfo(input)).Name));
                ImageToPDFConverter image = new ImageToPDFConverter(input, target);
                Console.WriteLine("Merging : " + Path.GetFullPath(input));

                if (!Directory.Exists(Path.GetDirectoryName(target)))
                    Directory.CreateDirectory(Path.GetDirectoryName(target));
                image.MergeFolderOfImagesToPDF();
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }

        public static void MergePDFToPDF(PDFToolkitArguements toolkitArgs, string input)
        {
            try
            {
                if (string.IsNullOrEmpty(toolkitArgs.MergeWildCards))
                {
                    toolkitArgs.MergeWildCards = "*.pdf"; ;
                }
                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%dirname.pdf";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%dirname", (new DirectoryInfo(input)).Name));
                var files = Directory.GetFiles(input, toolkitArgs.MergeWildCards, SearchOption.TopDirectoryOnly).ToList();
                Console.WriteLine("Merging : " + Path.GetFullPath(input));
                PDFMerger merge = new PDFMerger();
                if (!Directory.Exists(Path.GetDirectoryName(target)))
                    Directory.CreateDirectory(Path.GetDirectoryName(target));
                merge.MergePDFs(files, target);
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }

        public static void ProcessFile(string input, PDFToolkitArguements toolkitArgs)
        {
            Console.WriteLine("Splitting : " + input);
            try
            {
                if (!Path.GetExtension(input).ToLower().Contains("pdf"))
                {
                    Console.WriteLine("Input File {0} must be a pdf File", input);
                    if (!toolkitArgs.OnErrorContinue)
                    {
                        Console.WriteLine("Halting Job Because Continue On Error is set to false");
                        Environment.Exit(1);
                    }
                    else
                    {
                        return;
                    }
                }
                PDFDocument pdfFile;

                if (toolkitArgs.Password == null)
                    pdfFile = new PDFDocument(input);
                else
                    pdfFile = new PDFDocument(input, toolkitArgs.Password);
                PDFSplitter splitter = new PDFSplitter(pdfFile);
                splitter.OutputFileName = Path.GetFileNameWithoutExtension(toolkitArgs.OutputFile);
                splitter.OutputFilePath = toolkitArgs.TargetFolder;
                int startPage = 1;
                int endpage = pdfFile.NumberOfPages;

                if (toolkitArgs.EndPage > 0)
                {
                    endpage = toolkitArgs.EndPage;
                }

                if (toolkitArgs.StartPage > 0)
                {
                    startPage = toolkitArgs.StartPage;
                }
                switch (toolkitArgs.Operation)
                {
                    case "SplitPageRange":
                        if (toolkitArgs.RepeatingRange == -1)
                            splitter.SplitByPageRanges(toolkitArgs.SplitRange);
                        else
                            splitter.SplitByRepeatingPageRanges(toolkitArgs.SplitRange, toolkitArgs.RepeatingRange);
                        break;

                    case "SplitBookmark":
                        splitter.SplitByTopLevelBookmarks();
                        break;

                    case "SplitNormal":
                        {
                            if (toolkitArgs.RepeatingRange < 1)
                            {
                                toolkitArgs.RepeatingRange = 1;
                            }
                            splitter.SplitByRepeatingNumber(startPage, endpage, toolkitArgs.RepeatingRange);
                        }

                        break;
                }
                pdfFile.Close();
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }
    }
}