﻿using Aquaforest.PDF;
using Aquaforest.PDF.Font;
using System;
using System.Drawing;
using System.IO;

namespace PDFToolkitCMD
{
    internal class StampPDFHandler
    {
        public static void ProcessFile(string input, PDFToolkitArguements toolkitArgs)
        {
            PDFDocument pdfFile;
            try
            {
                if (!Path.GetExtension(input).ToLower().Contains("pdf"))
                {
                    Console.WriteLine("Input File {0} must be a pdf File", input);
                    if (!toolkitArgs.OnErrorContinue)
                    {
                        Console.WriteLine("Halting Job Because Continue On Error is set to false");
                        Environment.Exit(1);
                    }
                    else
                    {
                        return;
                    }
                }

                if (string.IsNullOrEmpty(toolkitArgs.OutputFile))
                {
                    toolkitArgs.OutputFile = "%filename_stamp.pdf";
                }

                string target = Path.Combine(toolkitArgs.TargetFolder, toolkitArgs.OutputFile.Replace("%filename", Path.GetFileNameWithoutExtension(input)));
                Console.WriteLine("Stamping : " + Path.GetFullPath(input));

                if (toolkitArgs.Password == null)
                {
                    pdfFile = new PDFDocument(input);
                }
                else
                {
                    pdfFile = new PDFDocument(input, toolkitArgs.Password);
                }
                PDFStamper stamp = new PDFStamper(pdfFile, target);
                if (toolkitArgs.Font != null)
                {
                    if (toolkitArgs.Font.EndsWith(".ttf"))
                        stamp.Font = PDFTrueTypeFont.LoadTTF(pdfFile, toolkitArgs.Font);
                    else
                        stamp.Font = PDFType1Font.GetStandardFont(toolkitArgs.Font);
                }
                if (toolkitArgs.FontSize > 0)
                {
                    stamp.FontSize = (Int32)toolkitArgs.FontSize;
                }

                if (Color.FromName(toolkitArgs.StampColor) != null)
                    stamp.StampColor = Color.FromName(toolkitArgs.StampColor);
                stamp.StampOpacity = toolkitArgs.Opacity;
                switch (toolkitArgs.Operation)
                {
                    case "StampPDFText":
                        if (toolkitArgs.PageNumber != -1)
                            stamp.StampPDFTextAsImage(toolkitArgs.StampObject, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord, toolkitArgs.PageNumber);
                        else
                            stamp.StampPDFTextAsImage(toolkitArgs.StampObject, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord);
                        break;

                    case "StampPDFImage":
                        if (toolkitArgs.PageNumber != -1)
                            stamp.StampPDFImage(toolkitArgs.StampObject, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord, toolkitArgs.PageNumber);
                        else
                            stamp.StampPDFImage(toolkitArgs.StampObject, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord);
                        break;

                    case "StampVariable":
                        if (toolkitArgs.PageNumber != -1)
                            stamp.StampVariable(toolkitArgs.StampObject, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord, toolkitArgs.PageNumber);
                        else
                            stamp.StampVariable(toolkitArgs.StampObject, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord);
                        break;

                    case "StampPageNumberBates":
                        if (toolkitArgs.PageNumber != -1)
                            stamp.StampPageNumberBates(toolkitArgs.BateLength, toolkitArgs.StampSuffix, toolkitArgs.StampPrefix, toolkitArgs.StartNumber, toolkitArgs.StartPage, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord);
                        else
                            stamp.StampPageNumberBates(toolkitArgs.BateLength, toolkitArgs.StampSuffix, toolkitArgs.StampPrefix, toolkitArgs.StartNumber, toolkitArgs.StartPage, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord);
                        break;

                    case "StampPageNumber":
                        if (toolkitArgs.PageNumber != -1)
                            stamp.StampPageNumber(toolkitArgs.StartNumber, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord, toolkitArgs.StartPage);
                        else
                            stamp.StampPageNumber(toolkitArgs.StartNumber, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord, toolkitArgs.StartPage);
                        break;

                    case "StampTextAsString":
                        if (toolkitArgs.PageNumber != -1)
                            stamp.StampTextAsString(toolkitArgs.StampObject, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord, toolkitArgs.PageNumber);
                        else
                            stamp.StampTextAsString(toolkitArgs.StampObject, (Int32)toolkitArgs.XCoord, (Int32)toolkitArgs.YCoord);
                        break;
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);

                if (!toolkitArgs.OnErrorContinue)
                {
                    Console.WriteLine("Halting Job Because Continue On Error is set to false");
                    Environment.Exit(1);
                }
            }
        }
    }
}